@@ -492,7 +492,8 @@ class ProxyHandler(HubOAuthenticated, WebSocketHandlerMixin):
         self.ws = await pingable_ws_connect(request=request,
                                             on_message_callback=message_cb, on_ping_callback=ping_cb,
                                             on_get_headers_callback=headers_cb,
-                                            subprotocols=self.subprotocols)
+                                            subprotocols=self.subprotocols,
+                                            max_message_size=self.settings['websocket_max_message_size'])
         self._record_activity()
         self.log.info('Websocket connection established to {}'.format(client_uri))
 
@@ -654,6 +655,7 @@ class SuperviseAndProxyHandler(LocalProxyHandler):
         self.origin_host = None
 
         self.ready_check_path = '/'
+        self.ready_timeout = 10
 
         super().__init__(*args, **kwargs)
 
@@ -697,7 +699,7 @@ class SuperviseAndProxyHandler(LocalProxyHandler):
         """
         Return timeout (in s) to wait before giving up on process readiness
         """
-        return 5
+        return self.ready_timeout
 
     async def _http_ready_func(self, p):
         url = 'http://localhost:{}{}'.format(self.port, self.ready_check_path)
@@ -882,7 +884,7 @@ class SuperviseAndProxyHandler(LocalProxyHandler):
         self.origin_host = self.request.host
 
 
-def _make_serverproxy_handler(name, command, environment, timeout, absolute_url, port, ready_check_path, gitwrapper, mappath):
+def _make_serverproxy_handler(name, command, environment, absolute_url, port, ready_check_path, ready_timeout, gitwrapper, mappath):
     """
     Create a SuperviseAndProxyHandler subclass with given parameters
     """
@@ -897,6 +899,7 @@ def _make_serverproxy_handler(name, command, environment, timeout, absolute_url,
             self.mappath = mappath
             self.ready_check_path = ready_check_path
             self.gitwrapper = gitwrapper
+            self.ready_timeout = ready_timeout
 
         @property
         def process_args(self):
@@ -969,8 +972,4 @@ def _make_serverproxy_handler(name, command, environment, timeout, absolute_url,
             else:
                 return self._render_template(environment)
 
-        def get_timeout(self):
-            return timeout
-
     return _Proxy
-
